/***********************************************************
 * $Id: HttpAwareSupport.java 58 2010-10-04 14:12:19Z gwt $
 * 
 * HTTP/AOP Utilities of clazzes.org
 * http://www.clazzes.org
 *
 * Created: 21.09.2010
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.http.aop;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.clazzes.util.aop.ThreadLocalManager;

/**
 * A base class for services or interceptors, which need access to a
 * thread-bound http request and/or http response previously bound to the
 * current thread by an RPC servlet.
 */
public class HttpAwareSupport {
	
	private String requestThreadLocalKey;
	private String responseThreadLocalKey;

	/**
	 * @return The HTTP request previously bound to the current thread by an RPC servlet.
	 */
	protected HttpServletRequest getThreadLocalRequest() {
		return ThreadLocalManager.getBoundResource(this.requestThreadLocalKey);
	}
	
	/**
	 * @return The HTTP response previously bound to the current thread by an RPC servlet.
	 */
	protected HttpServletResponse getThreadLocalResponse() {
		return ThreadLocalManager.getBoundResource(this.responseThreadLocalKey);
	}
	
	/**
	 * @return the thread local key under which the {@link HttpServletRequest} has been bound to
	 *        the current thread using {@link ThreadLocalManager#bindResource(String, Object)}.
	 */
	public String getRequestThreadLocalKey() {
		return requestThreadLocalKey;
	}

	/**
	 * @param requestThreadLocalKey the thread local key under which the
	 *        {@link HttpServletRequest} has been bound to the current thread using
	 *        {@link ThreadLocalManager#bindResource(String, Object)} to set.
	 */
	public void setRequestThreadLocalKey(String requestThreadLocalKey) {
		this.requestThreadLocalKey = requestThreadLocalKey;
	}
	
	/**
	 * @return the thread local key under which the {@link HttpServletResponse} has been bound to
	 *        the current thread using {@link ThreadLocalManager#bindResource(String, Object)}.
	 */
	public String getResponseThreadLocalKey() {
		return responseThreadLocalKey;
	}

	/**
	 * @param responseThreadLocalKey the thread local key under which the
	 *        {@link HttpServletResponse} has been bound to the current thread using
	 *        {@link ThreadLocalManager#bindResource(String, Object)} to set.
	 */
	public void setResponseThreadLocalKey(String responseThreadLocalKey) {
		this.responseThreadLocalKey = responseThreadLocalKey;
	}
}
