/***********************************************************
 * $Id: HttpCheckLoginService.java 407 2011-06-03 12:19:09Z gwt $
 * 
 * HTTP/AOP Utilities of clazzes.org
 * http://www.clazzes.org
 *
 * Created: 19.05.2011
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.http.aop;

import java.security.Principal;

import org.clazzes.util.http.sec.CheckLoginService;
import org.clazzes.util.http.sec.HttpLoginService;
import org.clazzes.util.http.sec.LoginRequiredException;

/**
 * A default server-side implementation of a login service operating on
 * behalf of a {@link HttpLoginService} instance and a thread-bound http request.
 */
public class HttpCheckLoginService extends HttpAwareSupport implements CheckLoginService {

	private HttpLoginService loginService;
	
	/* (non-Javadoc)
	 * @see org.clazzes.gwt.sec.shared.CheckLoginService#checkLogin()
	 */
	public String checkLogin() throws LoginRequiredException {
		
		Principal user = this.loginService.checkLogin(this.getThreadLocalRequest());
		
		if (user == null)
			throw new LoginRequiredException(this.loginService.getLoginUrl());
		
		return user.getName();
	}

	/* (non-Javadoc)
	 * @see org.clazzes.gwt.sec.shared.CheckLoginService#checkPermission(java.lang.String)
	 */
	public boolean checkPermission(String contextUrl) {
		
		return this.loginService.checkPermission(this.getThreadLocalRequest(),contextUrl);
	}

	public String getLoginUrl() {
		
		return this.loginService.getLoginUrl();
	}

	public void logout() {
		this.loginService.logout(this.getThreadLocalRequest());
	}

	/**
	 * @return the external login service to use.
	 */
	public HttpLoginService getLoginService() {
		return this.loginService;
	}

	/**
	 * @param loginService the external login service to set.
	 */
	public void setLoginService(HttpLoginService loginService) {
		this.loginService = loginService;
	}
}
