/***********************************************************
 * $Id: HttpContextProvider.java 391 2011-05-19 09:07:10Z gwt $
 * 
 * HTTP/AOP Utilities of clazzes.org
 * http://www.clazzes.org
 *
 * Created: 18.05.2011
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.http.aop;

import org.aopalliance.intercept.MethodInvocation;
import org.clazzes.util.http.sec.HttpLoginService;

/**
 * An implementation of this interface provides a security context URL
 * from a remote method invocation.
 * 
 * The context URL is usually passed to
 * {@link HttpLoginService#checkPermission(javax.servlet.http.HttpServletRequest, String)}.
 */
public interface HttpContextProvider {

	/**
	 * Get the context URL from a method invocation.
	 * @param invocation The method invocation to consider.
	 * @return An URL to check permission using 
	 *  {@link HttpLoginService#checkPermission(javax.servlet.http.HttpServletRequest, String)}
	 */
	public String getContextUrl(MethodInvocation invocation);
}
